<!--
https://pypi.org/project/readme-generator/
https://pypi.org/project/python-readme-generator/
-->

[![](https://img.shields.io/badge/OS-macOS-blue.svg?longCache=True)]()
[![](https://img.shields.io/badge/language-AppleScript-blue.svg?longCache=True)]()

#### Installation
```bash
$ [sudo] pip install mac-volume
```

#### Scripts usage
command|`usage`
-|-
`volume` |`usage: volume [volume]`

#### Examples
```bash
$ volume 30
$ volume
30
```

<p align="center">
    <a href="https://pypi.org/project/python-readme-generator/">python-readme-generator</a>
</p>